[Android] put back opensles for gingerbread and hc

Thomas Guillem git at videolan.org
Thu Feb 12 17:33:27 CET 2015


vlc-ports/android | branch: master | Thomas Guillem <thomas at gllm.fr> | Thu Feb 12 17:32:28 2015 +0100| [b6ebbbfb03dfc87ac7db22b66a33c66ca4f3cfe3] | committer: Thomas Guillem

put back opensles for gingerbread and hc

> http://git.videolan.org/gitweb.cgi/vlc-ports/android.git/?a=commit;h=b6ebbbfb03dfc87ac7db22b66a33c66ca4f3cfe3
---

 vlc-android/src/org/videolan/vlc/gui/PreferencesActivity.java |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/vlc-android/src/org/videolan/vlc/gui/PreferencesActivity.java b/vlc-android/src/org/videolan/vlc/gui/PreferencesActivity.java
index 7bcf379..c21627d 100644
--- a/vlc-android/src/org/videolan/vlc/gui/PreferencesActivity.java
+++ b/vlc-android/src/org/videolan/vlc/gui/PreferencesActivity.java
@@ -206,7 +206,7 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
 
         // Audio output
         ListPreference aoutPref = (ListPreference) findPreference("aout");
-        if (LibVlcUtil.isICSOrLater()) {
+        if (LibVlcUtil.isGingerbreadOrLater()) {
             int aoutEntriesId = R.array.aouts;
             int aoutEntriesIdValues = R.array.aouts_values;
             aoutPref.setEntries(aoutEntriesId);
@@ -221,7 +221,7 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
                     aoutPref.setValue(String.valueOf(LibVLC.AOUT_AUDIOTRACK));
             }
         } else {
             /* only audiotrack before ics */
             PreferenceGroup group = (PreferenceGroup) findPreference("advanced_prefs_group");
             group.removePreference(aoutPref);
         }
@@ -221,7 +221,7 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
             }
         } else {
-            /* only audiotrack before ics */
+            /* only audiotrack before gingerbread */
             PreferenceGroup group = (PreferenceGroup) findPreference("advanced_prefs_group");
             group.removePreference(aoutPref);



More information about the Android mailing list